@@ -24,11 +24,6 @@ sub AUTOLOAD {
 
 sub DESTROY { }
 
-sub new {
-  my $class = shift;
-  return bless [@_], ref $class || $class;
-}
-
 sub c { __PACKAGE__->new(@_) }
 
 sub compact {
@@ -65,6 +60,11 @@ sub map {
   return $self->new(map { $_->$cb } @$self);
 }
 
+sub new {
+  my $class = shift;
+  return bless [@_], ref $class || $class;
+}
+
 sub pluck {
   my ($self, $method, @args) = @_;
   return $self->map(sub { $_->$method(@args) });
@@ -131,7 +131,12 @@ Mojo::Collection - Collection
 
 =head1 DESCRIPTION
 
-L<Mojo::Collection> is a container for collections.
+L<Mojo::Collection> is an array-based container for collections.
+
+  # Access array directly to manipulate collection
+  my $collection = Mojo::Collection->new(1 .. 25);
+  $collection->[23] += 100;
+  say for @$collection;
 
 =head1 FUNCTIONS
 
@@ -147,12 +152,6 @@ Construct a new array-based L<Mojo::Collection> object.
 
 L<Mojo::Collection> implements the following methods.
 
-=head2 new
-
-  my $collection = Mojo::Collection->new(1, 2, 3);
-
-Construct a new array-based L<Mojo::Collection> object.
-
 =head2 compact
 
   my $new = $collection->compact;
@@ -225,6 +224,12 @@ callback and is also available as C<$_>.
 
   my $doubled = $collection->map(sub { $_ * 2 });
 
+=head2 new
+
+  my $collection = Mojo::Collection->new(1, 2, 3);
+
+Construct a new array-based L<Mojo::Collection> object.
+
 =head2 pluck
 
   my $new = $collection->pluck($method);
@@ -282,21 +287,30 @@ Alias for L<Mojo::Base/"tap">.
 
 Create a new collection without duplicate elements.
 
-=head1 ELEMENT METHODS
+=head1 AUTOLOAD
 
-In addition to the methods above, you can also call methods provided by all
-elements in the collection directly and create a new collection from the
+In addition to the L</"METHODS"> above, you can also call methods provided by
+all elements in the collection directly and create a new collection from the
 results, similar to L</"pluck">.
 
   push @$collection, Mojo::DOM->new("<div><h1>$_</h1></div>") for 1 .. 9;
   say $collection->find('h1')->type('h2')->prepend_content('Test ')->root;
 
-=head1 ELEMENTS
+=head1 OPERATORS
 
-Direct array reference access to elements is also possible.
+L<Mojo::Collection> overloads the following operators.
 
-  say $collection->[23];
-  say for @$collection;
+=head2 bool
+
+  my $bool = !!$collection;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$collection";
+
+Stringify elements in collection and L</"join"> them with newlines.
 
 =head1 SEE ALSO
 
